Pop3mail.DateConverter (pop3mail v1.3.4) View Source

Date conversions and date utilities

Link to this section Summary

Functions

Convert date from email header to a standard date format: YYYYMMDD_HHMMSS

add zero's at left side of the number

Link to this section Functions

Specs

convert_date(String.t()) :: String.t()

Convert date from email header to a standard date format: YYYYMMDD_HHMMSS

datestr - must be conform RFC 2822 date format

Link to this function

zero_pad(natural_number, len \\ 2)

Specs

add zero's at left side of the number