Pop3mail.DateConverter (pop3mail v1.3.3) View Source
Date conversions and date utilities
Link to this section Summary
Functions
Convert date from email header to a standard date format: YYYYMMDD_HHMMSS
add zero's at left side of the number
Link to this section Functions
Specs
Convert date from email header to a standard date format: YYYYMMDD_HHMMSS
datestr - must be conform RFC 2822 date format
Specs
zero_pad(non_neg_integer(), non_neg_integer()) :: String.t()
add zero's at left side of the number